/*
 *
 * Copyright © 2007 Sun Microsystems, Inc. All rights reserved.
 * Use is subject to license terms.
 */
package com.sun.perseus.demo;

import java.io.InputStream;
import java.io.IOException;

import javax.microedition.midlet.MIDlet;

import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;

import javax.microedition.m2g.SVGImage;
import javax.microedition.m2g.SVGAnimator;

import com.sun.svg.component.LoadingScreen;
import com.sun.svg.util.DefaultSVGAnimator;

public class ContactListMidlet extends MIDlet 
                               implements LoadingScreen.Listener {
    /**
     * List of skins
     */
    private static final String[] SKIN_DIRS = { "/skin1", "/skin2" };
    
    /**
     * List of skin file sizes
     */
    private static final int[] SKINS_SIZES = { 38000, 38000 };
    
    /**
     * This contact list's skin index.
     */
    private final int skinIndex;

    private final Display display;

    private ContactListScreen contactListScreen;

    private boolean loading;

    /** Creates a new instance of ContactListMidlet */
    protected ContactListMidlet(int skinIndex) {
        this.skinIndex = skinIndex;
        this.display = Display.getDisplay(this);
    }

    synchronized public void startApp() {
        if ((contactListScreen == null) && (!loading)) {
            InputStream imageStream = 
                    ContactListMidlet.class.getResourceAsStream(
                        SKIN_DIRS[skinIndex] + "/loadScreen.svg");
            if (imageStream == null) {
                destroyApp(false);
                notifyDestroyed();
                return;
            }
            SVGImage loadingImage;
            try {
                try {
                    loadingImage = 
                            (SVGImage)SVGImage.createImage(imageStream, null);
                } finally {
                    try {
                        imageStream.close();
                    } catch (IOException e) {
                        // ignore
                    }
                }
            } catch (IOException e) {
                destroyApp(false);
                notifyDestroyed();
                return;
            }

            SVGAnimator loadingAnimator = 
                    DefaultSVGAnimator.createAnimator(loadingImage);
            Canvas loadingCanvas = (Canvas)loadingAnimator.getTargetComponent();
            display.setCurrent(loadingCanvas);

            // start the loading of the contact list svg file             
            new LoadingScreen(loadingAnimator, loadingImage, 
                    SKIN_DIRS[skinIndex] + "/list.svg", SKINS_SIZES[skinIndex], 
                    this);
            
            loading = true;
        }
    }

    synchronized public void svgImageLoaded(SVGImage svgImage) {
        SVGAnimator contactListAnimator = 
                DefaultSVGAnimator.createAnimator(svgImage);
        ContactListSource contactListSource = new ContactListSource();
        Canvas contactListCanvas = 
                (Canvas)contactListAnimator.getTargetComponent();
        display.setCurrent(contactListCanvas);

        contactListScreen = new ContactListScreen(contactListAnimator, svgImage, 
                                                  contactListSource);        
        
        loading = false;    
    }
    
    public void pauseApp() {
    }
    
    public void destroyApp(boolean unconditional) {
    }
}




