/*
 *
 * Copyright © 2007 Sun Microsystems, Inc. All rights reserved.
 * Use is subject to license terms.
 */
package com.sun.svg.component;

import org.w3c.dom.Document;
import org.w3c.dom.svg.SVGElement;

/**
 * Simple helper class to bind an SVG <code>&lt;text&gt;</code> element with a 
 * data source.
 */
public class SVGTextBinding {
    /**
     * The text binding's default value.
     */
    public static final String DEFAULT_TEXT_VALUE = "---";
    
    /**
     * The id of the bound <text> element.
     */
    protected String id;
    
    /**
     * A reference to the bound <text> element instance in the 
     * current skin.
     */
    protected SVGElement text;
    
    /**
     * @param id the &lt;text&gt; element in which the "#text" trait should 
     * be set.
     */
    public SVGTextBinding(final String id) {
        if (id == null || "".equals(id)) {
            throw new IllegalArgumentException();
        }
        
        this.id = id;
    }
    
    /**
     * @param doc - the <code>Document</code> skin where an element with this
     * binding's id should be found.
     */
    public void hookSkin(final Document doc) {
        text = (SVGElement) doc.getElementById(id);
        
        if (text == null) {
            throw new IllegalArgumentException("SVGTextBinding: Element with id " + id +
                    " does not exist in skin");
        }
        
        // Initially set the text to the default value.
        set(DEFAULT_TEXT_VALUE);        
    }

    /**
     * Sets the binding's value.
     * @param value the new value to display in the text element.
     */
    public void set(String value) {
        if (value == null) {
            value = "null";
        }
        text.setTrait("#text", value);
    }
}
